@@ -1,5 +1,7 @@
 import json
+import os
 import re
+import tempfile
 from abc import ABCMeta, abstractmethod
 from datetime import datetime
 from enum import Enum
@@ -25,6 +27,12 @@ KNOWN_PKG_TYPES = [
     "hex",
     "packagist",
     "uvi",
+    "apk",
+    "deb",
+    "rpm",
+    "linux",
+    "swid",
+    "oss-fuzz",
 ]
 
 # Maps variations of string to package types
@@ -40,6 +48,10 @@ PKG_TYPES_MAP = {
     "crates": ["rust", "crates.io", "cargo"],
     "pub": ["dart"],
     "hex": ["elixir"],
+    "github": ["actions"],
+    "apk": ["alpine"],
+    "deb": ["ubuntu", "debian"],
+    "rpm": ["redhat", "centos"],
 }
 
 # CPE Regex
@@ -497,3 +509,23 @@ class VulnerabilityOccurrence:
             "related_urls": self.related_urls,
             "effective_severity": str(self.effective_severity),
         }
+
+
+class CustomNamedTemporaryFile:
+    def __init__(self, mode="wb", delete=True):
+        self._mode = mode
+        self._delete = delete
+
+    def __enter__(self):
+        # Generate a random temporary file name
+        file_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+        # Ensure the file is created
+        open(file_name, "x").close()
+        # Open the file in the given mode
+        self._tempFile = open(file_name, self._mode)
+        return self._tempFile
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self._tempFile.close()
+        if self._delete:
+            os.remove(self._tempFile.name)
