@@ -89,12 +89,14 @@ class NvdSource(VulnerabilitySource):
                 tf.write(chunk)
             tf.flush()
             with gzip.open(tf.name, "rb") as gzipjf:
-                cve_data = gzipjf.read()
                 try:
+                    cve_data = gzipjf.read()
                     json_data = json_lib.loads(cve_data)
                     return self.convert(json_data)
                 except Exception:
-                    logging.warning("Exception while parsing NVD CVE feed")
+                    logging.warning(
+                        f"Exception while parsing NVD CVE feed for {year}. Please try after some time"
+                    )
                     return None
 
     def convert(self, cve_data):
